Advanced
========

.. currentmodule:: chaospy

User-defined distribution
-------------------------

.. autosummary::
   :template: distribution.rst
   :toctree: ../../api

   UserDistribution

Kernel Estimation
-----------------

.. autosummary::
   :template: distribution.rst
   :toctree: ../../api

   GaussianKDE

Mixtures
--------

.. autosummary::
   :template: distribution.rst
   :toctree: ../../api

   GaussianMixture
